package com.ruoyi.project.plant.service.impl;

import com.ruoyi.project.plant.domain.TStaffmgrRecord;
import com.ruoyi.project.plant.mapper.TStaffmgrRecordMapper;
import com.ruoyi.project.plant.service.ITStaffmgrRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 人员操作记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-27
 */
@Service
public class TStaffmgrRecordServiceImpl implements ITStaffmgrRecordService 
{
    @Autowired
    private TStaffmgrRecordMapper tStaffmgrRecordMapper;

    /**
     * 查询人员操作记录
     * 
     * @param recordId 人员操作记录主键
     * @return 人员操作记录
     */
    @Override
    public TStaffmgrRecord selectTStaffmgrRecordByRecordId(Long recordId)
    {
        return tStaffmgrRecordMapper.selectTStaffmgrRecordByRecordId(recordId);
    }

    /**
     * 查询人员操作记录列表
     * 
     * @param tStaffmgrRecord 人员操作记录
     * @return 人员操作记录
     */
    @Override
    public List<TStaffmgrRecord> selectTStaffmgrRecordList(TStaffmgrRecord tStaffmgrRecord)
    {
        return tStaffmgrRecordMapper.selectTStaffmgrRecordList(tStaffmgrRecord);
    }

    /**
     * 新增人员操作记录
     * 
     * @param tStaffmgrRecord 人员操作记录
     * @return 结果
     */
    @Override
    public int insertTStaffmgrRecord(TStaffmgrRecord tStaffmgrRecord)
    {
        return tStaffmgrRecordMapper.insertTStaffmgrRecord(tStaffmgrRecord);
    }

    /**
     * 修改人员操作记录
     * 
     * @param tStaffmgrRecord 人员操作记录
     * @return 结果
     */
    @Override
    public int updateTStaffmgrRecord(TStaffmgrRecord tStaffmgrRecord)
    {
        return tStaffmgrRecordMapper.updateTStaffmgrRecord(tStaffmgrRecord);
    }

    /**
     * 批量删除人员操作记录
     * 
     * @param recordIds 需要删除的人员操作记录主键
     * @return 结果
     */
    @Override
    public int deleteTStaffmgrRecordByRecordIds(Long[] recordIds)
    {
        return tStaffmgrRecordMapper.deleteTStaffmgrRecordByRecordIds(recordIds);
    }

    /**
     * 删除人员操作记录信息
     * 
     * @param recordId 人员操作记录主键
     * @return 结果
     */
    @Override
    public int deleteTStaffmgrRecordByRecordId(Long recordId)
    {
        return tStaffmgrRecordMapper.deleteTStaffmgrRecordByRecordId(recordId);
    }
}
